Struct VecSink
Source pub struct VecSink {
inner: Arc<Mutex<Vec<Decision>>>,
}
In-memory sink used by tests and the WASM bridge.
Removes and returns all recorded decisions.
Panics
Panics if another thread poisoned the sink mutex.
Returns a copy of all recorded decisions without removing them.
Panics
Panics if another thread poisoned the sink mutex.
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Returns the “default value” for a type.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The alignment of pointer.
The type for initializers.
Initializes a with the given initializer.
Read more
Mutably dereferences the given pointer.
Read more
Drops the object pointed to by the given pointer.
Read more
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.
Perform a zero-cost type-safe upcast to a wider ref type within the Wasm
bindgen generics type system.
Read more
Perform a zero-cost type-safe upcast to a wider type within the Wasm
bindgen generics type system.
Read more